.. _modelling-overview:

Modelling
=========

Arbor is feature complete for real world modeling, and the user community is busy collaborating with us to build complex models. Best practices, tips, tricks and howtos will be documented here as the community gains experience.

In the meantime, we encouraged the use of our Github Discussions board for public discussions on modelling: `Github Discussions <https://github.com/arbor-sim/arbor/discussions>`_.

Under the `arbor-contrib <https://github.com/arbor-contrib/>`_ organisation, some users have already shared their models. You can peruse these at your leisure, and of course add yours if you like to share! `Please contact us <https://docs.arbor-sim.org/en/stable/contrib/index.html#get-in-touch>`_ to have your model added to our list.
